@@ -15,7 +15,7 @@ int32_t SPVM__Net__SSLeay__PEM__read_bio_X509(SPVM_ENV* env, SPVM_VALUE* stack)
   void* obj_bp = stack[0].oval;
   
   if (!obj_bp) {
-    return env->die(env, stack, "The BIO $bp must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die_v2(env, stack, "The BIO $bp must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   BIO* bp = env->get_pointer(env, stack, obj_bp);
@@ -28,7 +28,7 @@ int32_t SPVM__Net__SSLeay__PEM__read_bio_X509(SPVM_ENV* env, SPVM_VALUE* stack)
     char* ssl_error_string = env->get_stack_tmp_buffer(env, stack);
     ERR_error_string_n(ssl_error, ssl_error_string, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE);
     
-    env->die(env, stack, "[OpenSSL Error]PEM_read_bio_X509 failed:%s.", ssl_error_string, __func__, FILE_NAME, __LINE__);
+    env->die_v2(env, stack, "[OpenSSL Error]PEM_read_bio_X509 failed:%s.", __func__, FILE_NAME, __LINE__, ssl_error_string);
     
     if (ERR_GET_REASON(ssl_error) == PEM_R_NO_START_LINE) {
       int32_t tmp_error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error::PEM_R_NO_START_LINE", &error_id, __func__, FILE_NAME, __LINE__);
@@ -63,7 +63,7 @@ int32_t SPVM__Net__SSLeay__PEM__read_bio_X509_CRL(SPVM_ENV* env, SPVM_VALUE* sta
   void* obj_bp = stack[0].oval;
   
   if (!obj_bp) {
-    return env->die(env, stack, "The BIO $bp must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die_v2(env, stack, "The BIO $bp must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   BIO* bp = env->get_pointer(env, stack, obj_bp);
@@ -76,7 +76,7 @@ int32_t SPVM__Net__SSLeay__PEM__read_bio_X509_CRL(SPVM_ENV* env, SPVM_VALUE* sta
     char* ssl_error_string = env->get_stack_tmp_buffer(env, stack);
     ERR_error_string_n(ssl_error, ssl_error_string, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE);
     
-    env->die(env, stack, "[OpenSSL Error]PEM_read_bio_X509_CRL failed:%s.", ssl_error_string, __func__, FILE_NAME, __LINE__);
+    env->die_v2(env, stack, "[OpenSSL Error]PEM_read_bio_X509_CRL failed:%s.", __func__, FILE_NAME, __LINE__, ssl_error_string);
     
     if (ERR_GET_REASON(ssl_error) == PEM_R_NO_START_LINE) {
       int32_t tmp_error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error::PEM_R_NO_START_LINE", &error_id, __func__, FILE_NAME, __LINE__);
@@ -111,7 +111,7 @@ int32_t SPVM__Net__SSLeay__PEM__read_bio_PrivateKey(SPVM_ENV* env, SPVM_VALUE* s
   void* obj_bp = stack[0].oval;
   
   if (!obj_bp) {
-    return env->die(env, stack, "The BIO $bp must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die_v2(env, stack, "The BIO $bp must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   BIO* bp = env->get_pointer(env, stack, obj_bp);
@@ -124,7 +124,7 @@ int32_t SPVM__Net__SSLeay__PEM__read_bio_PrivateKey(SPVM_ENV* env, SPVM_VALUE* s
     char* ssl_error_string = env->get_stack_tmp_buffer(env, stack);
     ERR_error_string_n(ssl_error, ssl_error_string, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE);
     
-    env->die(env, stack, "[OpenSSL Error]read_bio_PrivateKey failed:%s.", ssl_error_string, __func__, FILE_NAME, __LINE__);
+    env->die_v2(env, stack, "[OpenSSL Error]read_bio_PrivateKey failed:%s.", __func__, FILE_NAME, __LINE__, ssl_error_string);
     
     if (ERR_GET_REASON(ssl_error) == PEM_R_NO_START_LINE) {
       int32_t tmp_error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error::PEM_R_NO_START_LINE", &error_id, __func__, FILE_NAME, __LINE__);
