@@ -19,7 +19,7 @@ int32_t SPVM__Net__SSLeay__RAND__seed(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t num = stack[1].ival;
   
   if (!obj_buf) {
-    return env->die(env, stack, "The buffer $buf must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die_v2(env, stack, "The buffer $buf must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const char* buf = env->get_chars(env, stack, obj_buf);
@@ -47,7 +47,7 @@ int32_t SPVM__Net__SSLeay__RAND__load_file(SPVM_ENV* env, SPVM_VALUE* stack) {
   int64_t max_bytes = stack[1].lval;
   
   if (!obj_filename) {
-    return env->die(env, stack, "The filename $filename must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die_v2(env, stack, "The filename $filename must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const char* filename = env->get_chars(env, stack, obj_filename);
@@ -60,7 +60,7 @@ int32_t SPVM__Net__SSLeay__RAND__load_file(SPVM_ENV* env, SPVM_VALUE* stack) {
     char* ssl_error_string = env->get_stack_tmp_buffer(env, stack);
     ERR_error_string_n(ssl_error, ssl_error_string, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE);
     
-    env->die(env, stack, "[OpenSSL Error]RAND_load_file failed:%s.", ssl_error_string, __func__, FILE_NAME, __LINE__);
+    env->die_v2(env, stack, "[OpenSSL Error]RAND_load_file failed:%s.", __func__, FILE_NAME, __LINE__, ssl_error_string);
     
     int32_t tmp_error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
     if (error_id) { return error_id; }
