@@ -316,6 +316,18 @@ The X509 object $cacert must be defined. Otherwise an exception is thrown.
 
 If add_client_CA failed, an exception is thrown with C<eval_error_id> set to the basic type ID of L<Net::SSLeay::Error|SPVM::Net::SSLeay::Error> class.
 
+=head2 use_certificate
+
+C<method use_certificate : int ($x : L<Net::SSLeay::X509|SPVM::Net::SSLeay::X509>);>
+
+Calls native L<SSL_CTX_use_certificate|https://docs.openssl.org/master/man3/SSL_CTX_use_certificate> function given the pointer value of the instance, the pointer value of $x, and returns its return value.
+
+Exceptions:
+
+The X509 object $x must be defined. Otherwise an exception is thrown.
+
+If SSL_CTX_use_certificate failed, an exception is thrown with C<eval_error_id> set to the basic type ID of L<Net::SSLeay::Error|SPVM::Net::SSLeay::Error> class.
+
 =head2 add_extra_chain_cert
 
 C<method add_extra_chain_cert : long ($x509 : L<Net::SSLeay::X509|SPVM::Net::SSLeay::X509>);>
@@ -357,7 +369,7 @@ The native callback function is defined by the following native code:
     SSL* ssl = (SSL*)X509_STORE_CTX_get_ex_data(x509_store_ctx, SSL_get_ex_data_X509_STORE_CTX_idx());
     
     if (!ssl) {
-      env->die(env, stack, "X509_STORE_CTX_get_ex_data(x509_store_ctx, SSL_get_ex_data_X509_STORE_CTX_idx()) failed.", __func__, FILE_NAME, __LINE__);
+      env->die_v2(env, stack, "X509_STORE_CTX_get_ex_data(x509_store_ctx, SSL_get_ex_data_X509_STORE_CTX_idx()) failed.", __func__, FILE_NAME, __LINE__);
       
       env->print_exception_to_stderr(env, stack);
       
@@ -367,7 +379,7 @@ The native callback function is defined by the following native code:
     SSL_CTX* self = SSL_get_SSL_CTX(ssl);
     
     if (!self) {
-      env->die(env, stack, "SSL_get_SSL_CTX(ssl) failed.", __func__, FILE_NAME, __LINE__);
+      env->die_v2(env, stack, "SSL_get_SSL_CTX(ssl) failed.", __func__, FILE_NAME, __LINE__);
       
       env->print_exception_to_stderr(env, stack);
       
@@ -392,7 +404,7 @@ The native callback function is defined by the following native code:
     }
     
     if (!obj_cb) {
-      env->die(env, stack, "verify_callback field must be defined.", __func__, FILE_NAME, __LINE__);
+      env->die_v2(env, stack, "verify_callback field must be defined.", __func__, FILE_NAME, __LINE__);
       
       env->print_exception_to_stderr(env, stack);
       goto END_OF_FUNC;
@@ -481,7 +493,7 @@ The native callback function is defined by the following native code:
     }
     
     if (!obj_cb) {
-      env->die(env, stack, "alpn_select_cb field must be defined.", __func__, FILE_NAME, __LINE__);
+      env->die_v2(env, stack, "alpn_select_cb field must be defined.", __func__, FILE_NAME, __LINE__);
       
       env->print_exception_to_stderr(env, stack);
       goto END_OF_FUNC;
@@ -523,7 +535,7 @@ The native callback function is defined by the following native code:
     void* obj_out = env->get_elem_object(env, stack, obj_out_ref, 0);
     
     if (!obj_out) {
-      env->die(env, stack, "An output string for set_alpn_select_cb is not set.", __func__, FILE_NAME, __LINE__);
+      env->die_v2(env, stack, "An output string for set_alpn_select_cb is not set.", __func__, FILE_NAME, __LINE__);
       
       env->print_exception_to_stderr(env, stack);
       goto END_OF_FUNC;
@@ -615,7 +627,7 @@ The native callback function is defined by the following native code:
     }
     
     if (!obj_cb) {
-      env->die(env, stack, "default_passwd_cb field must be defined.", __func__, FILE_NAME, __LINE__);
+      env->die_v2(env, stack, "default_passwd_cb field must be defined.", __func__, FILE_NAME, __LINE__);
       
       env->print_exception_to_stderr(env, stack);
       goto END_OF_FUNC;
@@ -697,7 +709,7 @@ The native callback function is defined by the following native code:
     }
     
     if (!obj_cb) {
-      env->die(env, stack, "tlsext_servername_callback field must be defined.", __func__, FILE_NAME, __LINE__);
+      env->die_v2(env, stack, "tlsext_servername_callback field must be defined.", __func__, FILE_NAME, __LINE__);
       
       env->print_exception_to_stderr(env, stack);
       goto END_OF_FUNC;
