@@ -20,7 +20,7 @@ int32_t SPVM__Net__SSLeay__X509_EXTENSION__new(SPVM_ENV* env, SPVM_VALUE* stack)
     char* ssl_error_string = env->get_stack_tmp_buffer(env, stack);
     ERR_error_string_n(ssl_error, ssl_error_string, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE);
     
-    env->die(env, stack, "[OpenSSL Error]X509_EXTENSION_new failed:%s.", ssl_error_string, __func__, FILE_NAME, __LINE__);
+    env->die_v2(env, stack, "[OpenSSL Error]X509_EXTENSION_new failed:%s.", __func__, FILE_NAME, __LINE__, ssl_error_string);
     
     int32_t tmp_error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
     if (error_id) { return error_id; }
@@ -110,7 +110,7 @@ int32_t SPVM__Net__SSLeay__X509_EXTENSION__set_object(SPVM_ENV* env, SPVM_VALUE*
   X509_EXTENSION* self = env->get_pointer(env, stack, obj_self);
   
   if (!obj_object) {
-    return env->die(env, stack, "The ASN1_OBJECT object $obj must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die_v2(env, stack, "The ASN1_OBJECT object $obj must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   ASN1_OBJECT* object = env->get_pointer(env, stack, obj_object);
@@ -123,7 +123,7 @@ int32_t SPVM__Net__SSLeay__X509_EXTENSION__set_object(SPVM_ENV* env, SPVM_VALUE*
     char* ssl_error_string = env->get_stack_tmp_buffer(env, stack);
     ERR_error_string_n(ssl_error, ssl_error_string, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE);
     
-    env->die(env, stack, "[OpenSSL Error]X509_EXTENSION_set_object failed:%s.", ssl_error_string, __func__, FILE_NAME, __LINE__);
+    env->die_v2(env, stack, "[OpenSSL Error]X509_EXTENSION_set_object failed:%s.", __func__, FILE_NAME, __LINE__, ssl_error_string);
     
     int32_t tmp_error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
     if (error_id) { return error_id; }
@@ -155,7 +155,7 @@ int32_t SPVM__Net__SSLeay__X509_EXTENSION__set_critical(SPVM_ENV* env, SPVM_VALU
     char* ssl_error_string = env->get_stack_tmp_buffer(env, stack);
     ERR_error_string_n(ssl_error, ssl_error_string, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE);
     
-    env->die(env, stack, "[OpenSSL Error]X509_EXTENSION_set_critical failed:%s.", ssl_error_string, __func__, FILE_NAME, __LINE__);
+    env->die_v2(env, stack, "[OpenSSL Error]X509_EXTENSION_set_critical failed:%s.", __func__, FILE_NAME, __LINE__, ssl_error_string);
     
     int32_t tmp_error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
     if (error_id) { return error_id; }
@@ -180,7 +180,7 @@ int32_t SPVM__Net__SSLeay__X509_EXTENSION__set_data(SPVM_ENV* env, SPVM_VALUE* s
   X509_EXTENSION* self = env->get_pointer(env, stack, obj_self);
   
   if (!obj_data) {
-    return env->die(env, stack, "The ASN1_OCTET_STRING object $data must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die_v2(env, stack, "The ASN1_OCTET_STRING object $data must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   ASN1_OCTET_STRING* data = env->get_pointer(env, stack, obj_data);
@@ -193,7 +193,7 @@ int32_t SPVM__Net__SSLeay__X509_EXTENSION__set_data(SPVM_ENV* env, SPVM_VALUE* s
     char* ssl_error_string = env->get_stack_tmp_buffer(env, stack);
     ERR_error_string_n(ssl_error, ssl_error_string, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE);
     
-    env->die(env, stack, "[OpenSSL Error]X509_EXTENSION_set_data failed:%s.", ssl_error_string, __func__, FILE_NAME, __LINE__);
+    env->die_v2(env, stack, "[OpenSSL Error]X509_EXTENSION_set_data failed:%s.", __func__, FILE_NAME, __LINE__, ssl_error_string);
     
     int32_t tmp_error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
     if (error_id) { return error_id; }
