@@ -19,17 +19,17 @@ int32_t SPVM__Net__SSLeay__X509_STORE_CTX__get1_issuer(SPVM_ENV* env, SPVM_VALUE
   void* obj_x = stack[2].oval;
   
   if (!(obj_issuer_ref && env->length(env, stack, obj_issuer_ref) == 1)) {
-    return env->die(env, stack, "The output array of the Net::SSLeay::X509 $issuer_ref must be a 1-length array.", __func__, FILE_NAME, __LINE__);
+    return env->die_v2(env, stack, "The output array of the Net::SSLeay::X509 $issuer_ref must be a 1-length array.", __func__, FILE_NAME, __LINE__);
   }
   
   if (!obj_ctx) {
-    return env->die(env, stack, "The Net::SSLeay::X509_STORE_CTX object $ctx must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die_v2(env, stack, "The Net::SSLeay::X509_STORE_CTX object $ctx must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   X509_STORE_CTX* ctx = env->get_pointer(env, stack, obj_ctx);
   
   if (!obj_x) {
-    return env->die(env, stack, "The X509 object $x must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die_v2(env, stack, "The X509 object $x must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   X509* x = env->get_pointer(env, stack, obj_x);
@@ -43,7 +43,7 @@ int32_t SPVM__Net__SSLeay__X509_STORE_CTX__get1_issuer(SPVM_ENV* env, SPVM_VALUE
     char* ssl_error_string = env->get_stack_tmp_buffer(env, stack);
     ERR_error_string_n(ssl_error, ssl_error_string, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE);
     
-    env->die(env, stack, "[OpenSSL Error]X509_STORE_CTX_get1_issuer failed:%s.", ssl_error_string, __func__, FILE_NAME, __LINE__);
+    env->die_v2(env, stack, "[OpenSSL Error]X509_STORE_CTX_get1_issuer failed:%s.", __func__, FILE_NAME, __LINE__, ssl_error_string);
     
     int32_t tmp_error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
     if (error_id) { return error_id; }
